IdaLy is a data augmentation library for industrial data.
You can use any methods of industrial data augmentation in your python file by installing our library.
You can also download the platform(Idap, an executable file) to finish augmentation task conveniently.